@@ -4,7 +4,7 @@ import numpy as np
 import pytest
 
 import tiledb
-from tiledb import _fragment
+from tiledb.main import PyFragmentInfo
 from tiledb.tests.common import DiskTestCase
 
 
@@ -15,7 +15,7 @@ class FragmentInfoTest(DiskTestCase):
             pytest.skip("Only run FragmentInfo test with TileDB>=2.2")
 
     def test_uri_dne(self):
-        fragment_info = _fragment.info("does_not_exist")
+        fragment_info = PyFragmentInfo("does_not_exist")
         with self.assertRaises(tiledb.TileDBError):
             fragment_info.load()
 
@@ -51,8 +51,7 @@ class FragmentInfoTest(DiskTestCase):
         )
         self.assertEqual(fragments_info.sparse, (False, False, False))
         self.assertEqual(fragments_info.timestamp_range, ((1, 1), (2, 2), (3, 3)))
-        self.assertEqual(fragments_info.to_vacuum_num, 0)
-        self.assertEqual(fragments_info.to_vacuum_uri, [])
+        self.assertEqual(fragments_info.to_vacuum, ())
 
         for idx, frag in enumerate(fragments_info):
             self.assertEqual(frag.cell_num, 3)
@@ -125,7 +124,7 @@ class FragmentInfoTest(DiskTestCase):
 
         tiledb.DenseArray.create(uri, schema)
 
-        fragment_info = _fragment.info(uri)
+        fragment_info = PyFragmentInfo(uri)
 
         for fragment_idx in range(fragments):
             timestamp = fragment_idx + 1
@@ -191,7 +190,7 @@ class FragmentInfoTest(DiskTestCase):
 
         tiledb.SparseArray.create(uri, schema)
 
-        fragment_info = _fragment.info(uri)
+        fragment_info = PyFragmentInfo(uri)
 
         for fragment_idx in range(fragments):
             timestamp = fragment_idx + 1
@@ -271,7 +270,7 @@ class FragmentInfoTest(DiskTestCase):
             y = [-1.5, -1.25]
             T[x, y] = np.array(range(2))
 
-        fragment_info = _fragment.info(uri)
+        fragment_info = PyFragmentInfo(uri)
         fragment_info.load()
 
         x_dt = schema.domain.dim(0).dtype
@@ -332,7 +331,7 @@ class FragmentInfoTest(DiskTestCase):
             )
             T[dates] = np.array(range(3))
 
-        fragment_info = _fragment.info(uri)
+        fragment_info = PyFragmentInfo(uri)
         fragment_info.load()
 
         self.assertEqual(
@@ -391,7 +390,7 @@ class FragmentInfoTest(DiskTestCase):
             y_dims = [b"e", b"f"]
             T[x_dims, y_dims] = np.array([1, 2])
 
-        fragment_info = _fragment.info(uri)
+        fragment_info = PyFragmentInfo(uri)
         fragment_info.load()
 
         self.assertEqual(fragment_info.get_non_empty_domain(schema, 0, 0), ("a", "d"))
@@ -424,7 +423,7 @@ class FragmentInfoTest(DiskTestCase):
 
         tiledb.SparseArray.create(uri, schema)
 
-        fragment_info = _fragment.info(uri)
+        fragment_info = PyFragmentInfo(uri)
 
         with tiledb.SparseArray(uri, mode="w") as T:
             a = np.array([1, 2, 3, 4])
@@ -434,7 +433,7 @@ class FragmentInfoTest(DiskTestCase):
             b = np.array([1, 2])
             T[b] = b
 
-        fragment_info = _fragment.info(uri)
+        fragment_info = PyFragmentInfo(uri)
         fragment_info.load()
 
         self.assertEqual(fragment_info.cell_num(0), len(a))
@@ -453,7 +452,7 @@ class FragmentInfoTest(DiskTestCase):
 
         tiledb.DenseArray.create(uri, schema)
 
-        fragment_info = _fragment.info(uri)
+        fragment_info = PyFragmentInfo(uri)
 
         for fragment_idx in range(fragments):
             with tiledb.DenseArray(uri, mode="w") as T:
@@ -493,7 +492,7 @@ class FragmentInfoTest(DiskTestCase):
 
         tiledb.DenseArray.create(uri, schema)
 
-        fragment_info = _fragment.info(uri)
+        fragment_info = PyFragmentInfo(uri)
 
         for fragment_idx in range(fragments):
             with tiledb.DenseArray(uri, mode="w") as T:
